@@ -39,9 +39,7 @@ impl Default for Compression {
 }
 
 impl Compression {
-    // TODO: remove in 0.7.
-    #[deprecated(since = "0.6.3", note = "should be private")]
-    pub fn encoding(&self) -> Option<&'static str> {
+    pub(crate) fn encoding(&self) -> Option<&'static str> {
         match self {
             Compression::None => Option::None,
             #[cfg(feature = "lz4")]
