@@ -4,14 +4,14 @@
 #[macro_use]
 extern crate static_assertions;
 
-use std::{collections::HashMap, time::Duration};
+use std::{collections::HashMap, sync::Arc, time::Duration};
 
 use hyper::client::connect::HttpConnector;
 
 pub use clickhouse_derive::Row;
 
-use self::error::Result;
 pub use self::{compression::Compression, row::Row};
+use self::{error::Result, http_client::HttpClient};
 
 pub mod error;
 pub mod insert;
@@ -28,14 +28,11 @@ pub mod watch;
 mod buflist;
 mod compression;
 mod cursor;
+mod http_client;
 mod response;
 mod row;
 mod rowbinary;
 
-mod sealed {
-    pub trait Sealed {}
-}
-
 const TCP_KEEPALIVE: Duration = Duration::from_secs(60);
 
 // ClickHouse uses 3s by default.
@@ -44,7 +41,7 @@ const POOL_IDLE_TIMEOUT: Duration = Duration::from_secs(2);
 
 #[derive(Clone)]
 pub struct Client {
-    client: hyper::Client<HttpConnector>,
+    client: Arc<dyn HttpClient>,
 
     url: String,
     database: Option<String>,
@@ -65,8 +62,14 @@ impl Default for Client {
             .pool_idle_timeout(POOL_IDLE_TIMEOUT)
             .build(connector);
 
+        Self::with_http_client(client)
+    }
+}
+
+impl Client {
+    pub fn with_http_client(client: impl HttpClient) -> Self {
         Self {
-            client,
+            client: Arc::new(client),
             url: String::new(),
             database: None,
             user: None,
@@ -75,9 +78,7 @@ impl Default for Client {
             options: HashMap::new(),
         }
     }
-}
 
-impl Client {
     // TODO: use `url` crate?
     pub fn with_url(mut self, url: impl Into<String>) -> Self {
         self.url = url.into();
